//
//  QGImageManager.h
//  Immutation
//
//  Created by Matthew McCowan on 7/11/07.
//  Copyright 2007 Quickgigs, Inc. All rights reserved.
//

#import "QGFoundation.h"
#import "QGImage.h"
#import "QGChainController.h"

@interface QGImageManager : QGObject
{
	// Instance
	NSArray         *fileTypes;
	NSMutableArray  *contents;
	NSMutableSet    *contentPaths;
	unsigned         current;
	unsigned         untitledCount;
	
	NSSavePanel     *savePanel;
	NSString        *lastSaveExtension;
	
	// Outlet
	IBOutlet QGChainController *chainController;
}

// Initialization


// Properties
- (NSArray *) fileTypes;
- (NSString *) saveFileType;
- (NSString *) filenameWithSaveFileType:(NSString *)baseFilename;


// Current
- (void) setCurrent:(int)newCurrent;
- (int) current;
- (BOOL) hasCurrentFilteredImageBeenSaved;
- (void) setLastSaveExtension:(NSString *)newLastSaveExtension;
- (NSString *)lastSaveExtension;

// Elements
- (int) count;
- (BOOL) hasImages;
- (id) getImageAt:(unsigned)index;
- (QGImage *) getCurrentImage;
- (void) addImageFromData:(NSData *)data;
- (void) addImageFromPath:(NSString *)path;
- (void) addImagesFromPaths:(NSArray *)paths;
- (void) removeImage;
- (void) removeAllImages;
- (BOOL) hasPath:(NSString *)path;
- (BOOL) writeImageToPath:(NSString *)path;


// Actions
- (IBAction) newImageFromClipboard:(id)sender;
- (IBAction) openImage:(id)sender;
- (IBAction) closeImage:(id)sender;
- (IBAction) closeAllImages:(id)sender;
- (IBAction) saveImage:(id)sender;
- (IBAction) saveImageAs:(id)sender;
- (IBAction) saveAllImages:(id)sender;
- (IBAction) cut:(id)sender;
- (IBAction) copy:(id)sender;
- (IBAction) paste:(id)sender;
- (IBAction) delete:(id)sender;


// Actions Helpers
- (void) openPanelDidEnd:(NSOpenPanel *)panel returnCode:(int)returnCode contextInfo:(void *)x;
- (void) saveImagePanelDidEnd:(NSSavePanel *)panel returnCode:(int)returnCode contextInfo:(void *)x;
- (void) saveAllImagesPanelDidEnd:(NSSavePanel *)panel returnCode:(int)returnCode contextInfo:(void *)x;


// Misc
- (BOOL) application:(NSApplication *)theApplication openFile:(NSString *)filename;

@end
